@@ -1,7 +1,8 @@
+use anyhow::Result;
 use tracing::error;
 use yazi_shared::env_exists;
 
-use crate::{CLOSE, ESCAPE, NVIM, START, TMUX};
+use crate::{CLOSE, ESCAPE, Emulator, NVIM, START, TMUX};
 
 pub struct Mux;
 
@@ -25,7 +26,7 @@ impl Mux {
 		}
 
 		let child = std::process::Command::new("tmux")
-			.args(["set", "-p", "allow-passthrough", "all"])
+			.args(["set", "-p", "allow-passthrough", "on"])
 			.stdin(std::process::Stdio::null())
 			.stdout(std::process::Stdio::null())
 			.stderr(std::process::Stdio::piped())
@@ -35,18 +36,26 @@ impl Mux {
 			Ok(output) if output.status.success() => return 2,
 			Ok(output) => {
 				error!(
-					"Running `tmux set -p allow-passthrough all` failed: {:?}, {}",
+					"Running `tmux set -p allow-passthrough on` failed: {:?}, {}",
 					output.status,
 					String::from_utf8_lossy(&output.stderr)
 				);
 			}
 			Err(err) => {
-				error!("Failed to spawn `tmux set -p allow-passthrough all`: {err}");
+				error!("Failed to spawn `tmux set -p allow-passthrough on`: {err}");
 			}
 		}
 		1
 	}
 
+	pub fn tmux_drain() -> Result<()> {
+		if *TMUX == 2 && !*NVIM {
+			crossterm::execute!(std::io::stderr(), crossterm::style::Print(Mux::csi("\x1b[5n")))?;
+			_ = futures::executor::block_on(Emulator::read_until_dsr());
+		}
+		Ok(())
+	}
+
 	pub fn tmux_sixel_flag() -> &'static str {
 		let stdout = std::process::Command::new("tmux")
 			.args(["-LwU0dju1is5", "-f/dev/null", "start", ";", "display", "-p", "#{sixel_support}"])
