@@ -1,12 +1,13 @@
-mod args;
-mod package;
+yazi_macro::mod_pub!(package);
+
+yazi_macro::mod_flat!(args);
 
-use args::*;
 use clap::Parser;
 
 #[tokio::main]
 async fn main() -> anyhow::Result<()> {
 	yazi_shared::init();
+	yazi_fs::init();
 
 	if std::env::args_os().nth(1).is_some_and(|s| s == "-V" || s == "--version") {
 		println!(
@@ -19,10 +20,47 @@ async fn main() -> anyhow::Result<()> {
 	}
 
 	match Args::parse().command {
+		Command::Emit(cmd) => {
+			yazi_boot::init_default();
+			yazi_dds::init();
+			if let Err(e) =
+				yazi_dds::Client::shot("dds-emit", CommandPub::receiver()?, &cmd.body()?).await
+			{
+				eprintln!("Cannot emit command: {e}");
+				std::process::exit(1);
+			}
+		}
+
+		Command::EmitTo(cmd) => {
+			yazi_boot::init_default();
+			yazi_dds::init();
+			if let Err(e) = yazi_dds::Client::shot("dds-emit", cmd.receiver, &cmd.body()?).await {
+				eprintln!("Cannot emit command: {e}");
+				std::process::exit(1);
+			}
+		}
+
+		Command::Pack(cmd) => {
+			package::init()?;
+			if cmd.install {
+				package::Package::install_from_config("plugin", false).await?;
+				package::Package::install_from_config("flavor", false).await?;
+			} else if cmd.list {
+				package::Package::list_from_config("plugin").await?;
+				package::Package::list_from_config("flavor").await?;
+			} else if cmd.upgrade {
+				package::Package::install_from_config("plugin", true).await?;
+				package::Package::install_from_config("flavor", true).await?;
+			} else if let Some(repo) = cmd.add {
+				package::Package::add_to_config(&repo).await?;
+			}
+		}
+
 		Command::Pub(cmd) => {
 			yazi_boot::init_default();
 			yazi_dds::init();
-			if let Err(e) = yazi_dds::Client::shot(&cmd.kind, cmd.receiver()?, &cmd.body()?).await {
+			if let Err(e) = yazi_dds::Client::shot(&cmd.kind, CommandPub::receiver()?, &cmd.body()?).await
+			{
 				eprintln!("Cannot send message: {e}");
 				std::process::exit(1);
 			}
@@ -44,31 +82,6 @@ async fn main() -> anyhow::Result<()> {
 
 			tokio::signal::ctrl_c().await?;
 		}
-
-		Command::Pack(cmd) => {
-			package::init();
-			package::Package::migrate().await?;
-			if cmd.install {
-				package::Package::install_from_config("plugin", false).await?;
-				package::Package::install_from_config("flavor", false).await?;
-			} else if cmd.list {
-				package::Package::list_from_config("plugin").await?;
-				package::Package::list_from_config("flavor").await?;
-			} else if cmd.upgrade {
-				package::Package::install_from_config("plugin", true).await?;
-				package::Package::install_from_config("flavor", true).await?;
-			} else if let Some(mut repo) = cmd.add {
-				// TODO: remove this in the future
-				if repo.contains("#") {
-					repo = repo.replace("#", ":");
-					println!(
-						"WARNING: `#` has been deprecated in Yazi 0.3.1, please use `:` instead. See https://github.com/sxyazi/yazi/issues/1471 for more information."
-					);
-				}
-
-				package::Package::add_to_config(&repo).await?;
-			}
-		}
 	}
 
 	Ok(())
