@@ -1,38 +1,11 @@
-use anyhow::{bail, Context, Result};
+use anyhow::{Context, Result, bail};
 use tokio::fs;
 use toml_edit::{Array, DocumentMut, InlineTable, Item, Value};
-use yazi_shared::Xdg;
+use yazi_fs::Xdg;
 
 use super::Package;
 
 impl Package {
-	// TODO: remove this in the future
-	pub(crate) async fn migrate() -> Result<()> {
-		let path = Xdg::config_dir().join("package.toml");
-		let mut doc = Self::ensure_config(&fs::read_to_string(&path).await.unwrap_or_default())?;
-
-		fn impl_(deps: &mut Array) -> Result<()> {
-			for dep in deps.iter_mut() {
-				let dep = dep.as_inline_table_mut().context("Dependency must be an inline table")?;
-				let use_ = dep.get("use").and_then(|d| d.as_str()).context("Missing `use` field")?;
-				if use_.contains("#") {
-					dep["use"] = use_.replace("#", ":").into();
-				}
-				if let Some(commit) = dep.get("commit").map(ToOwned::to_owned) {
-					dep.remove("commit");
-					dep.insert("rev", commit);
-				}
-			}
-			Ok(())
-		}
-
-		impl_(doc["plugin"]["deps"].as_array_mut().unwrap())?;
-		impl_(doc["flavor"]["deps"].as_array_mut().unwrap())?;
-
-		fs::write(path, doc.to_string()).await?;
-		Ok(())
-	}
-
 	pub(crate) async fn add_to_config(use_: &str) -> Result<()> {
 		let mut package = Self::new(use_, None);
 		let Some(name) = package.name() else { bail!("Invalid package `use`") };
@@ -73,8 +46,8 @@ impl Package {
 		let deps = deps.as_array_mut().context("`deps` must be an array")?;
 		for dep in deps.iter_mut() {
 			let dep = dep.as_inline_table_mut().context("Dependency must be an inline table")?;
-			let use_ = dep.get("use").and_then(|d| d.as_str()).context("Missing `use` field")?;
-			let rev = dep.get("rev").and_then(|d| d.as_str());
+			let use_ = dep.get("use").and_then(Value::as_str).context("Missing `use` field")?;
+			let rev = dep.get("rev").and_then(Value::as_str);
 
 			let mut package = Package::new(use_, rev);
 			if upgrade {
@@ -108,8 +81,11 @@ impl Package {
 		println!("{section}s:");
 
 		for dep in deps {
-			if let Some(Value::String(use_)) = dep.as_inline_table().and_then(|t| t.get("use")) {
-				println!("\t{}", use_.value());
+			let Some(dep) = dep.as_inline_table() else { continue };
+			match (dep.get("use").and_then(Value::as_str), dep.get("rev").and_then(Value::as_str)) {
+				(Some(use_), None) => println!("\t{use_}"),
+				(Some(use_), Some(rev)) => println!("\t{use_} ({rev})"),
+				_ => {}
 			}
 		}
 		Ok(())
@@ -146,7 +122,7 @@ impl Package {
 		fn same(v: &Value, name: &str) -> bool {
 			v.as_inline_table()
 				.and_then(|t| t.get("use"))
-				.and_then(|v| v.as_str())
+				.and_then(Value::as_str)
 				.is_some_and(|s| Package::new(s, None).name() == Some(name))
 		}
 
