@@ -1,23 +1,23 @@
+use yazi_macro::render;
 use yazi_proxy::CompletionProxy;
-use yazi_shared::{event::Cmd, render, InputError};
+use yazi_shared::{errors::InputError, event::CmdCow};
 
 use crate::input::Input;
 
-pub struct Opt {
+struct Opt {
 	submit: bool,
 }
 
-impl From<Cmd> for Opt {
-	fn from(c: Cmd) -> Self { Self { submit: c.bool("submit") } }
+impl From<CmdCow> for Opt {
+	fn from(c: CmdCow) -> Self { Self { submit: c.bool("submit") } }
 }
 impl From<bool> for Opt {
 	fn from(submit: bool) -> Self { Self { submit } }
 }
 
 impl Input {
-	pub fn close(&mut self, opt: impl Into<Opt>) {
-		let opt = opt.into() as Opt;
-
+	#[yazi_codegen::command]
+	pub fn close(&mut self, opt: Opt) {
 		if self.completion {
 			CompletionProxy::close();
 		}
