@@ -1,12 +1,12 @@
 use yazi_config::keymap::Key;
-use yazi_shared::event::Cmd;
+use yazi_shared::event::CmdCow;
 
 use crate::input::{Input, InputMode};
 
-pub struct Opt;
+struct Opt;
 
-impl From<Cmd> for Opt {
-	fn from(_: Cmd) -> Self { Self }
+impl From<CmdCow> for Opt {
+	fn from(_: CmdCow) -> Self { Self }
 }
 
 impl Input {
