@@ -1,21 +1,22 @@
-use yazi_shared::{event::{Cmd, Data}, render};
+use yazi_macro::render;
+use yazi_shared::event::{CmdCow, Data};
 
 use crate::manager::Tabs;
 
-pub struct Opt {
+struct Opt {
 	step:     isize,
 	relative: bool,
 }
 
-impl From<Cmd> for Opt {
-	fn from(c: Cmd) -> Self {
+impl From<CmdCow> for Opt {
+	fn from(c: CmdCow) -> Self {
 		Self { step: c.first().and_then(Data::as_isize).unwrap_or(0), relative: c.bool("relative") }
 	}
 }
 
 impl Tabs {
-	pub fn switch(&mut self, opt: impl Into<Opt>) {
-		let opt = opt.into() as Opt;
+	#[yazi_codegen::command]
+	pub fn switch(&mut self, opt: Opt) {
 		let idx = if opt.relative {
 			(self.cursor as isize + opt.step).rem_euclid(self.items.len() as isize) as usize
 		} else {
