@@ -1,17 +1,18 @@
+use yazi_fs::{File, FilesOp, expand_path};
 use yazi_proxy::ManagerProxy;
-use yazi_shared::{event::{Cmd, Data}, fs::{expand_path, File, FilesOp, Url}};
+use yazi_shared::{event::CmdCow, url::Url};
 
 use crate::tab::Tab;
 
-pub struct Opt {
+struct Opt {
 	target: Url,
 }
 
-impl From<Cmd> for Opt {
-	fn from(mut c: Cmd) -> Self {
-		let mut target = c.take_first().and_then(Data::into_url).unwrap_or_default();
+impl From<CmdCow> for Opt {
+	fn from(mut c: CmdCow) -> Self {
+		let mut target = c.take_first_url().unwrap_or_default();
 		if target.is_regular() {
-			target.set_path(expand_path(&target))
+			target = Url::from(expand_path(&target));
 		}
 
 		Self { target }
@@ -22,15 +23,14 @@ impl From<Url> for Opt {
 }
 
 impl Tab {
-	pub fn reveal(&mut self, opt: impl Into<Opt>) {
-		let opt = opt.into() as Opt;
-
+	#[yazi_codegen::command]
+	pub fn reveal(&mut self, opt: Opt) {
 		let Some(parent) = opt.target.parent_url() else {
 			return;
 		};
 
 		self.cd(parent.clone());
 		FilesOp::Creating(parent, vec![File::from_dummy(opt.target.clone(), None)]).emit();
-		ManagerProxy::hover(Some(opt.target), self.idx);
+		ManagerProxy::hover(Some(opt.target), self.id);
 	}
 }
