@@ -6,7 +6,6 @@ use yazi_fs::{Cha, File, Files, FilesOp, FolderStage, Step};
 use yazi_proxy::ManagerProxy;
 use yazi_shared::{Id, url::{Url, Urn}};
 
-#[derive(Default)]
 pub struct Folder {
 	pub url:   Url,
 	pub cha:   Cha,
@@ -20,6 +19,21 @@ pub struct Folder {
 	pub tracing: bool,
 }
 
+impl Default for Folder {
+	fn default() -> Self {
+		Self {
+			url:     Default::default(),
+			cha:     Default::default(),
+			files:   Files::new(MANAGER.show_hidden),
+			stage:   Default::default(),
+			offset:  Default::default(),
+			cursor:  Default::default(),
+			page:    Default::default(),
+			tracing: Default::default(),
+		}
+	}
+}
+
 impl From<&Url> for Folder {
 	fn from(url: &Url) -> Self { Self { url: url.clone(), ..Default::default() } }
 }
@@ -51,7 +65,10 @@ impl Folder {
 			FilesOp::IOErr(..) => self.files.update_ioerr(),
 
 			FilesOp::Creating(_, files) => self.files.update_creating(files),
-			FilesOp::Deleting(_, urns) => self.files.update_deleting(urns),
+			FilesOp::Deleting(_, urns) => {
+				let deleted = self.files.update_deleting(urns);
+				self.cursor -= deleted.into_iter().filter(|&i| i < self.cursor).count();
+			}
 			FilesOp::Updating(_, files) => _ = self.files.update_updating(files),
 			FilesOp::Upserting(_, files) => self.files.update_upserting(files),
 		}
