@@ -1,30 +1,28 @@
-use std::collections::HashMap;
-
-use yazi_config::{manager::SortBy, plugin::MAX_PREWORKERS, PLUGIN};
-use yazi_fs::Files;
-use yazi_shared::{fs::{File, Url}, MIME_DIR};
+use yazi_config::{PLUGIN, plugin::MAX_PREWORKERS};
+use yazi_fs::{File, Files, SortBy};
 
 use super::Tasks;
+use crate::manager::Mimetype;
 
 impl Tasks {
-	pub fn fetch_paged(&self, paged: &[File], mimetype: &HashMap<Url, String>) {
+	pub fn fetch_paged(&self, paged: &[File], mimetype: &Mimetype) {
 		let mut loaded = self.scheduler.prework.loaded.lock();
 		let mut tasks: [Vec<_>; MAX_PREWORKERS as usize] = Default::default();
 		for f in paged {
-			let mime =
-				if f.is_dir() { MIME_DIR } else { mimetype.get(&f.url).map(|s| &**s).unwrap_or_default() };
+			let mime = mimetype.by_file(f).unwrap_or_default();
 			let factors = |s: &str| match s {
 				"mime" => !mime.is_empty(),
+				"dummy" => f.cha.is_dummy(),
 				_ => false,
 			};
 
-			for p in PLUGIN.fetchers(&f.url, mime, factors) {
+			for g in PLUGIN.fetchers(&f.url, mime, factors) {
 				match loaded.get_mut(&f.url) {
-					Some(n) if *n & (1 << p.idx) != 0 => continue,
-					Some(n) => *n |= 1 << p.idx,
-					None => _ = loaded.insert(f.url.clone(), 1 << p.idx),
+					Some(n) if *n & (1 << g.idx) != 0 => continue,
+					Some(n) => *n |= 1 << g.idx,
+					None => _ = loaded.insert(f.url_owned(), 1 << g.idx),
 				}
-				tasks[p.idx as usize].push(f.clone());
+				tasks[g.idx as usize].push(f.clone());
 			}
 		}
 
@@ -36,23 +34,22 @@ impl Tasks {
 		}
 	}
 
-	pub fn preload_paged(&self, paged: &[File], mimetype: &HashMap<Url, String>) {
+	pub fn preload_paged(&self, paged: &[File], mimetype: &Mimetype) {
 		let mut loaded = self.scheduler.prework.loaded.lock();
 		for f in paged {
-			let mime =
-				if f.is_dir() { MIME_DIR } else { mimetype.get(&f.url).map(|s| &**s).unwrap_or_default() };
+			let mime = mimetype.by_file(f).unwrap_or_default();
 			for p in PLUGIN.preloaders(&f.url, mime) {
 				match loaded.get_mut(&f.url) {
 					Some(n) if *n & (1 << p.idx) != 0 => continue,
 					Some(n) => *n |= 1 << p.idx,
-					None => _ = loaded.insert(f.url.clone(), 1 << p.idx),
+					None => _ = loaded.insert(f.url_owned(), 1 << p.idx),
 				}
 				self.scheduler.preload_paged(p, f);
 			}
 		}
 	}
 
-	pub fn prework_affected(&self, affected: &[File], mimetype: &HashMap<Url, String>) {
+	pub fn prework_affected(&self, affected: &[File], mimetype: &Mimetype) {
 		let mask = PLUGIN.fetchers_mask();
 		{
 			let mut loaded = self.scheduler.prework.loaded.lock();
@@ -74,7 +71,7 @@ impl Tasks {
 			let loading = self.scheduler.prework.size_loading.read();
 			targets
 				.iter()
-				.filter(|f| f.is_dir() && !targets.sizes.contains_key(&f.url) && !loading.contains(&f.url))
+				.filter(|f| f.is_dir() && !targets.sizes.contains_key(f.urn()) && !loading.contains(&f.url))
 				.map(|f| &f.url)
 				.collect()
 		};
