@@ -1,24 +1,25 @@
 use mlua::{IntoLua, Lua, Value};
 use serde::{Deserialize, Serialize};
+use yazi_shared::Id;
 
 use super::Body;
 
 #[derive(Debug, Serialize, Deserialize)]
 pub struct BodyTab {
-	pub idx: usize,
+	pub id: Id,
 }
 
 impl BodyTab {
 	#[inline]
-	pub fn owned(idx: usize) -> Body<'static> { Self { idx }.into() }
+	pub fn owned(id: Id) -> Body<'static> { Self { id }.into() }
 }
 
-impl<'a> From<BodyTab> for Body<'a> {
+impl From<BodyTab> for Body<'_> {
 	fn from(value: BodyTab) -> Self { Self::Tab(value) }
 }
 
-impl IntoLua<'_> for BodyTab {
+impl IntoLua for BodyTab {
 	fn into_lua(self, lua: &Lua) -> mlua::Result<Value> {
-		lua.create_table_from([("idx", self.idx)])?.into_lua(lua)
+		lua.create_table_from([("idx", self.id.get())])?.into_lua(lua)
 	}
 }
