@@ -1,5 +1,5 @@
 use yazi_core::input::InputMode;
-use yazi_shared::{event::Cmd, Layer};
+use yazi_shared::{Layer, event::CmdCow};
 
 use crate::app::App;
 
@@ -12,12 +12,13 @@ impl<'a> Executor<'a> {
 	pub(super) fn new(app: &'a mut App) -> Self { Self { app } }
 
 	#[inline]
-	pub(super) fn execute(&mut self, cmd: Cmd, layer: Layer) {
+	pub(super) fn execute(&mut self, cmd: CmdCow, layer: Layer) {
 		match layer {
 			Layer::App => self.app(cmd),
 			Layer::Manager => self.manager(cmd),
 			Layer::Tasks => self.tasks(cmd),
-			Layer::Select => self.select(cmd),
+			Layer::Spot => self.spot(cmd),
+			Layer::Pick => self.pick(cmd),
 			Layer::Input => self.input(cmd),
 			Layer::Confirm => self.confirm(cmd),
 			Layer::Help => self.help(cmd),
@@ -26,7 +27,7 @@ impl<'a> Executor<'a> {
 		}
 	}
 
-	fn app(&mut self, cmd: Cmd) {
+	fn app(&mut self, cmd: CmdCow) {
 		macro_rules! on {
 			($name:ident) => {
 				if cmd.name == stringify!($name) {
@@ -46,7 +47,7 @@ impl<'a> Executor<'a> {
 		on!(resume);
 	}
 
-	fn manager(&mut self, cmd: Cmd) {
+	fn manager(&mut self, cmd: CmdCow) {
 		macro_rules! on {
 			(MANAGER, $name:ident $(,$args:expr)*) => {
 				if cmd.name == stringify!($name) {
@@ -55,7 +56,13 @@ impl<'a> Executor<'a> {
 			};
 			(ACTIVE, $name:ident $(,$args:expr)*) => {
 				if cmd.name == stringify!($name) {
-					return self.app.cx.manager.active_mut().$name(cmd, $($args),*);
+					return if let Some(tab) = cmd.get("tab") {
+						let Some(id) = tab.as_id() else { return };
+						let Some(tab) = self.app.cx.manager.tabs.find_mut(id) else { return };
+						tab.$name(cmd, $($args),*)
+					} else {
+						self.app.cx.manager.active_mut().$name(cmd, $($args),*)
+					};
 				}
 			};
 			(TABS, $name:ident) => {
@@ -65,20 +72,22 @@ impl<'a> Executor<'a> {
 			};
 		}
 
-		on!(MANAGER, update_task);
+		on!(MANAGER, update_tasks);
 		on!(MANAGER, update_files, &self.app.cx.tasks);
-		on!(MANAGER, update_mimetype, &self.app.cx.tasks);
+		on!(MANAGER, update_mimes, &self.app.cx.tasks);
 		on!(MANAGER, update_paged, &self.app.cx.tasks);
 		on!(MANAGER, update_yanked);
 		on!(MANAGER, hover);
 		on!(MANAGER, peek);
 		on!(MANAGER, seek);
+		on!(MANAGER, spot);
 		on!(MANAGER, refresh, &self.app.cx.tasks);
 		on!(MANAGER, quit, &self.app.cx.tasks);
 		on!(MANAGER, close, &self.app.cx.tasks);
 		on!(MANAGER, suspend);
 		on!(ACTIVE, escape);
-		on!(ACTIVE, preview);
+		on!(ACTIVE, update_peeked);
+		on!(ACTIVE, update_spotted);
 
 		// Navigation
 		on!(ACTIVE, arrow);
@@ -89,10 +98,12 @@ impl<'a> Executor<'a> {
 		on!(ACTIVE, cd);
 		on!(ACTIVE, reveal);
 
-		// Selection
+		// Toggle
+		on!(ACTIVE, toggle);
+		on!(ACTIVE, toggle_all);
+		on!(ACTIVE, visual_mode);
 		on!(ACTIVE, select);
 		on!(ACTIVE, select_all);
-		on!(ACTIVE, visual_mode);
 
 		// Operation
 		on!(MANAGER, open, &self.app.cx.tasks);
@@ -131,18 +142,18 @@ impl<'a> Executor<'a> {
 		on!(TABS, switch);
 		on!(TABS, swap);
 
-		match cmd.name.as_bytes() {
+		match cmd.name.as_str() {
 			// Tasks
-			b"tasks_show" => self.app.cx.tasks.toggle(()),
+			"tasks_show" => self.app.cx.tasks.toggle(()),
 			// Help
-			b"help" => self.app.cx.help.toggle(Layer::Manager),
+			"help" => self.app.cx.help.toggle(Layer::Manager),
 			// Plugin
-			b"plugin" => self.app.plugin(cmd),
+			"plugin" => self.app.plugin(cmd),
 			_ => {}
 		}
 	}
 
-	fn tasks(&mut self, cmd: Cmd) {
+	fn tasks(&mut self, cmd: CmdCow) {
 		macro_rules! on {
 			($name:ident) => {
 				if cmd.name == stringify!($name) {
@@ -172,11 +183,34 @@ impl<'a> Executor<'a> {
 		}
 	}
 
-	fn select(&mut self, cmd: Cmd) {
+	fn spot(&mut self, cmd: CmdCow) {
 		macro_rules! on {
 			($name:ident) => {
 				if cmd.name == stringify!($name) {
-					return self.app.cx.select.$name(cmd);
+					return self.app.cx.active_mut().spot.$name(cmd);
+				}
+			};
+		}
+
+		on!(arrow);
+		on!(close);
+		on!(swipe);
+		on!(copy);
+
+		match cmd.name.as_str() {
+			// Help
+			"help" => self.app.cx.help.toggle(Layer::Spot),
+			// Plugin
+			"plugin" => self.app.plugin(cmd),
+			_ => {}
+		}
+	}
+
+	fn pick(&mut self, cmd: CmdCow) {
+		macro_rules! on {
+			($name:ident) => {
+				if cmd.name == stringify!($name) {
+					return self.app.cx.pick.$name(cmd);
 				}
 			};
 		}
@@ -187,14 +221,14 @@ impl<'a> Executor<'a> {
 
 		match cmd.name.as_str() {
 			// Help
-			"help" => self.app.cx.help.toggle(Layer::Select),
+			"help" => self.app.cx.help.toggle(Layer::Pick),
 			// Plugin
 			"plugin" => self.app.plugin(cmd),
 			_ => {}
 		}
 	}
 
-	fn input(&mut self, cmd: Cmd) {
+	fn input(&mut self, cmd: CmdCow) {
 		macro_rules! on {
 			($name:ident) => {
 				if cmd.name == stringify!($name) {
@@ -250,7 +284,7 @@ impl<'a> Executor<'a> {
 		}
 	}
 
-	fn confirm(&mut self, cmd: Cmd) {
+	fn confirm(&mut self, cmd: CmdCow) {
 		macro_rules! on {
 			($name:ident $(,$args:expr)*) => {
 				if cmd.name == stringify!($name) {
@@ -264,7 +298,7 @@ impl<'a> Executor<'a> {
 		on!(close);
 	}
 
-	fn help(&mut self, cmd: Cmd) {
+	fn help(&mut self, cmd: CmdCow) {
 		macro_rules! on {
 			($name:ident) => {
 				if cmd.name == stringify!($name) {
@@ -285,7 +319,7 @@ impl<'a> Executor<'a> {
 		}
 	}
 
-	fn completion(&mut self, cmd: Cmd) {
+	fn completion(&mut self, cmd: CmdCow) {
 		macro_rules! on {
 			($name:ident) => {
 				if cmd.name == stringify!($name) {
@@ -309,7 +343,7 @@ impl<'a> Executor<'a> {
 		}
 	}
 
-	fn which(&mut self, cmd: Cmd) {
+	fn which(&mut self, cmd: CmdCow) {
 		macro_rules! on {
 			($name:ident) => {
 				if cmd.name == stringify!($name) {
