@@ -29,28 +29,35 @@ function Root:build()
 	}
 end
 
-function Root:render()
-	local children = self._base or {}
+function Root:reflow()
+	local components = { self }
 	for _, child in ipairs(self._children) do
-		children = ya.list_merge(children, ya.render_with(child))
+		components = ya.list_merge(components, child:reflow())
 	end
-	__yazi_check_and_warn_deprecated_api() -- TODO: remove this after 0.3.0 release
-	return children
+	return components
+end
+
+function Root:redraw()
+	local elements = self._base or {}
+	for _, child in ipairs(self._children) do
+		elements = ya.list_merge(elements, ya.redraw_with(child))
+	end
+	return elements
 end
 
 -- Mouse events
 function Root:click(event, up)
-	local c = ya.child_at(ui.Position { x = event.x, y = event.y }, self._children)
+	local c = ya.child_at(ui.Rect { x = event.x, y = event.y }, self._children)
 	return c and c:click(event, up)
 end
 
 function Root:scroll(event, step)
-	local c = ya.child_at(ui.Position { x = event.x, y = event.y }, self._children)
+	local c = ya.child_at(ui.Rect { x = event.x, y = event.y }, self._children)
 	return c and c:scroll(event, step)
 end
 
 function Root:touch(event, step)
-	local c = ya.child_at(ui.Position { x = event.x, y = event.y }, self._children)
+	local c = ya.child_at(ui.Rect { x = event.x, y = event.y }, self._children)
 	return c and c:touch(event, step)
 end
 
