@@ -2,32 +2,32 @@ local TEXT = "ABCDEFGHIJKLM\nNOPQRSTUVWXYZ\nabcdefghijklm\nnopqrstuvwxyz\n123456
 
 local M = {}
 
-function M:peek()
-	local start, cache = os.clock(), ya.file_cache(self)
-	if not cache or self:preload() ~= 1 then
+function M:peek(job)
+	local start, cache = os.clock(), ya.file_cache(job)
+	if not cache or self:preload(job) ~= 1 then
 		return
 	end
 
 	ya.sleep(math.max(0, PREVIEW.image_delay / 1000 + start - os.clock()))
-	ya.image_show(cache, self.area)
-	ya.preview_widgets(self, {})
+	ya.image_show(cache, job.area)
+	ya.preview_widgets(job, {})
 end
 
 function M:seek() end
 
-function M:preload()
-	local cache = ya.file_cache(self)
+function M:preload(job)
+	local cache = ya.file_cache(job)
 	if not cache or fs.cha(cache) then
 		return 1
 	end
 
-	local child, code = Command("magick"):args({
+	local status, err = Command("magick"):args({
 		"-size",
 		"800x560",
 		"-gravity",
 		"center",
 		"-font",
-		tostring(self.file.url),
+		tostring(job.file.url),
 		"-pointsize",
 		"64",
 		"xc:white",
@@ -37,15 +37,14 @@ function M:preload()
 		"+0+0",
 		TEXT,
 		"JPG:" .. tostring(cache),
-	}):spawn()
+	}):status()
 
-	if not child then
-		ya.err("spawn `magick` command returns " .. tostring(code))
+	if status then
+		return status.success and 1 or 2
+	else
+		ya.err("Failed to start `magick`, error: " .. err)
 		return 0
 	end
-
-	local status = child:wait()
-	return status and status.success and 1 or 2
 end
 
 return M
