@@ -67,8 +67,8 @@ local function setup(_, opts)
 			"cd",
 			function()
 				ya.manager_emit("shell", {
+					cwd = fs.cwd(),
 					orphan = true,
-					confirm = true,
 					"zoxide add " .. ya.quote(tostring(cx.active.current.cwd)),
 				})
 			end
