@@ -1,37 +1,44 @@
 use std::sync::atomic::{AtomicBool, Ordering};
 
 use mlua::{Lua, Table, UserData};
-use ratatui::layout::Rect;
 use yazi_adapter::ADAPTOR;
 
-use super::{RectRef, Renderable};
+use super::Area;
 
 pub static COLLISION: AtomicBool = AtomicBool::new(false);
 
-#[derive(Clone, Copy, Default)]
+#[derive(Clone, Copy, Debug, Default)]
 pub struct Clear {
-	pub area: ratatui::layout::Rect,
+	pub area: Area,
 }
 
 impl Clear {
-	pub fn install(lua: &Lua, ui: &Table) -> mlua::Result<()> {
-		let new = lua.create_function(|_, (_, area): (Table, RectRef)| Ok(Clear { area: *area }))?;
+	pub fn compose(lua: &Lua) -> mlua::Result<Table> {
+		let new = lua.create_function(|_, (_, area): (Table, Area)| Ok(Clear { area }))?;
 
 		let clear = lua.create_table()?;
 		clear.set_metatable(Some(lua.create_table_from([("__call", new)])?));
 
-		ui.raw_set("Clear", clear)
+		Ok(clear)
+	}
+
+	pub(super) fn render(
+		self,
+		buf: &mut ratatui::buffer::Buffer,
+		trans: impl FnOnce(yazi_config::popup::Position) -> ratatui::layout::Rect,
+	) {
+		<Self as ratatui::widgets::Widget>::render(Default::default(), self.area.transform(trans), buf);
 	}
 }
 
 impl ratatui::widgets::Widget for Clear {
-	fn render(self, area: Rect, buf: &mut ratatui::prelude::Buffer)
+	fn render(self, area: ratatui::layout::Rect, buf: &mut ratatui::prelude::Buffer)
 	where
 		Self: Sized,
 	{
 		ratatui::widgets::Clear.render(area, buf);
 
-		let Some(r) = ADAPTOR.shown_load().and_then(|r| overlap(&area, &r)) else {
+		let Some(r) = ADAPTOR.shown_load().and_then(|r| overlap(area, r)) else {
 			return;
 		};
 
@@ -45,24 +52,18 @@ impl ratatui::widgets::Widget for Clear {
 	}
 }
 
-impl Renderable for Clear {
-	fn area(&self) -> ratatui::layout::Rect { self.area }
-
-	fn render(self: Box<Self>, buf: &mut ratatui::buffer::Buffer) {
-		<Self as ratatui::widgets::Widget>::render(Default::default(), self.area, buf);
+impl UserData for Clear {
+	fn add_methods<M: mlua::UserDataMethods<Self>>(methods: &mut M) {
+		crate::impl_area_method!(methods);
 	}
-
-	fn clone_render(&self, buf: &mut ratatui::buffer::Buffer) { Box::new(*self).render(buf); }
 }
 
-impl UserData for Clear {}
-
 #[inline]
-const fn is_overlapping(a: &Rect, b: &Rect) -> bool {
+const fn is_overlapping(a: ratatui::layout::Rect, b: ratatui::layout::Rect) -> bool {
 	a.x < b.x + b.width && a.x + a.width > b.x && a.y < b.y + b.height && a.y + a.height > b.y
 }
 
-fn overlap(a: &Rect, b: &Rect) -> Option<Rect> {
+fn overlap(a: ratatui::layout::Rect, b: ratatui::layout::Rect) -> Option<ratatui::layout::Rect> {
 	if !is_overlapping(a, b) {
 		return None;
 	}
@@ -71,5 +72,5 @@ fn overlap(a: &Rect, b: &Rect) -> Option<Rect> {
 	let y = a.y.max(b.y);
 	let width = (a.x + a.width).min(b.x + b.width) - x;
 	let height = (a.y + a.height).min(b.y + b.height) - y;
-	Some(Rect { x, y, width, height })
+	Some(ratatui::layout::Rect { x, y, width, height })
 }
