@@ -8,8 +8,10 @@ use crate::{Error, bindings::{Cast, Cha}, file::File, url::{Url, UrlRef}};
 pub fn compose(lua: &Lua) -> mlua::Result<Table> {
 	let index = lua.create_function(|lua, (ts, key): (Table, mlua::String)| {
 		let value = match key.as_bytes().as_ref() {
+			b"cwd" => cwd(lua)?,
 			b"cha" => cha(lua)?,
 			b"write" => write(lua)?,
+			b"create" => create(lua)?,
 			b"remove" => remove(lua)?,
 			b"read_dir" => read_dir(lua)?,
 			b"unique_name" => unique_name(lua)?,
@@ -27,6 +29,13 @@ pub fn compose(lua: &Lua) -> mlua::Result<Table> {
 	Ok(fs)
 }
 
+fn cwd(lua: &Lua) -> mlua::Result<Function> {
+	lua.create_function(|lua, ()| match std::env::current_dir() {
+		Ok(p) => (Url::cast(lua, p)?, Value::Nil).into_lua_multi(lua),
+		Err(e) => (Value::Nil, Error::Io(e)).into_lua_multi(lua),
+	})
+}
+
 fn cha(lua: &Lua) -> mlua::Result<Function> {
 	lua.create_async_function(|lua, (url, follow): (UrlRef, Option<bool>)| async move {
 		let meta = if follow.unwrap_or(false) {
@@ -45,7 +54,22 @@ fn cha(lua: &Lua) -> mlua::Result<Function> {
 fn write(lua: &Lua) -> mlua::Result<Function> {
 	lua.create_async_function(|lua, (url, data): (UrlRef, mlua::String)| async move {
 		match fs::write(&*url, data.as_bytes()).await {
-			Ok(_) => (true, Value::Nil).into_lua_multi(&lua),
+			Ok(()) => (true, Value::Nil).into_lua_multi(&lua),
+			Err(e) => (false, Error::Io(e)).into_lua_multi(&lua),
+		}
+	})
+}
+
+fn create(lua: &Lua) -> mlua::Result<Function> {
+	lua.create_async_function(|lua, (type_, url): (mlua::String, UrlRef)| async move {
+		let result = match type_.as_bytes().as_ref() {
+			b"dir" => fs::create_dir(&*url).await,
+			b"dir_all" => fs::create_dir_all(&*url).await,
+			_ => Err("Creation type must be 'dir' or 'dir_all'".into_lua_err())?,
+		};
+
+		match result {
+			Ok(()) => (true, Value::Nil).into_lua_multi(&lua),
 			Err(e) => (false, Error::Io(e)).into_lua_multi(&lua),
 		}
 	})
@@ -62,7 +86,7 @@ fn remove(lua: &Lua) -> mlua::Result<Function> {
 		};
 
 		match result {
-			Ok(_) => (true, Value::Nil).into_lua_multi(&lua),
+			Ok(()) => (true, Value::Nil).into_lua_multi(&lua),
 			Err(e) => (false, Error::Io(e)).into_lua_multi(&lua),
 		}
 	})
