@@ -1,4 +1,5 @@
-use yazi_shared::{emit, event::Cmd, fs::Url, Layer};
+use yazi_macro::emit;
+use yazi_shared::{Layer, event::Cmd, url::Url};
 
 use crate::options::SearchOpt;
 
@@ -15,6 +16,11 @@ impl TabProxy {
 		emit!(Call(Cmd::args("reveal", &[target]), Layer::Manager));
 	}
 
+	#[inline]
+	pub fn arrow(step: isize) {
+		emit!(Call(Cmd::args("arrow", &[step]), Layer::Manager));
+	}
+
 	#[inline]
 	pub fn search_do(opt: SearchOpt) {
 		emit!(Call(
